@@ -1,4 +1,4 @@
-{-# LANGUAGE CPP #-}
+{-# LANGUAGE CPP, OverloadedStrings #-}
 {-|
 
 hledger-web - a hledger add-on providing a web interface.
@@ -10,10 +10,11 @@ Released under GPL version 3 or later.
 module Main
 where
 
+import Data.Conduit.Network (HostPreference(..))
 import Network.Wai.Handler.Warp (runSettings, defaultSettings, settingsPort)
 import Yesod.Default.Config
-import Yesod.Default.Main   (defaultMain)
-import Yesod.Logger (Logger, defaultDevelopmentLogger) --, logString)
+-- import Yesod.Default.Main   (defaultMain)
+import Yesod.Logger ({- Logger,-} defaultDevelopmentLogger) --, logString)
 
 import Prelude hiding (putStrLn)
 -- -- import Control.Concurrent (forkIO, threadDelay)
@@ -26,9 +27,8 @@ import Text.Printf
 
 import Hledger
 import Hledger.Cli hiding (progname,prognameandversion)
-import Hledger.Web.Settings (parseExtra)
-import Hledger.Utils.UTF8 (putStrLn)
-import Hledger.Web
+import Hledger.Utils.UTF8IOCompat (putStrLn)
+import Hledger.Web hiding (opts,j)
 
 
 main :: IO ()
@@ -38,17 +38,15 @@ main = do
   runWith opts
 
 runWith :: WebOpts -> IO ()
-runWith opts = run opts
-    where
-      run opts
-          | "help" `in_` (rawopts_ $ cliopts_ opts)            = putStr (showModeHelp webmode) >> exitSuccess
-          | "version" `in_` (rawopts_ $ cliopts_ opts)         = putStrLn prognameandversion >> exitSuccess
-          | "binary-filename" `in_` (rawopts_ $ cliopts_ opts) = putStrLn (binaryfilename progname)
-          | otherwise                                          = journalFilePathFromOpts (cliopts_ opts) >>= ensureJournalFile >> withJournalDo' opts web
+runWith opts
+  | "help" `in_` (rawopts_ $ cliopts_ opts)            = putStr (showModeHelp webmode) >> exitSuccess
+  | "version" `in_` (rawopts_ $ cliopts_ opts)         = putStrLn prognameandversion >> exitSuccess
+  | "binary-filename" `in_` (rawopts_ $ cliopts_ opts) = putStrLn (binaryfilename progname)
+  | otherwise                                          = journalFilePathFromOpts (cliopts_ opts) >>= ensureJournalFileExists >> withJournalDo' opts web
 
 withJournalDo' :: WebOpts -> (WebOpts -> Journal -> IO ()) -> IO ()
 withJournalDo' opts cmd = do
-  journalFilePathFromOpts (cliopts_ opts) >>= readJournalFile Nothing >>=
+  journalFilePathFromOpts (cliopts_ opts) >>= readJournalFile Nothing Nothing >>=
     either error' (cmd opts . journalApplyAliases (aliasesFromOpts $ cliopts_ opts))
 
 -- | The web command.
@@ -85,6 +83,8 @@ server baseurl port opts j = do
               appEnv = Development
             , appPort = port_ opts
             , appRoot = pack baseurl
+            , appHost = HostIPv4
+            , appExtra = Extra "" Nothing
             }
     logger <- defaultDevelopmentLogger
     app <- getApplication config logger
